Enum CallStatusResponse

pub enum CallStatusResponse {
    Simple(ExecutionStatus),
    Proof(CallProof),
}
Call status response.

This enum is serialized in JSON untagged. Hence, if the consumer knows the type of the response, she may parse it directly to ExecutionStatus or CallProof.

Variants



Simple(ExecutionStatus)

Simple response.



Proof(CallProof)

Response with a cryptographic proof of authenticity.