#[non_exhaustive]pub struct CallStatusQuery {
pub height: Height,
pub service_id: InstanceId,
pub with_proof: bool,
}Expand description
Query parameters to check the execution status of a before_transactions or
after_transactions call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.height: HeightHeight of a block.
service_id: InstanceIdNumerical service identifier.
with_proof: boolWhether to return the status with a cryptographic proof of authenticity.
Implementations
Sourceimpl CallStatusQuery
impl CallStatusQuery
Sourcepub fn new(height: Height, service_id: InstanceId) -> Self
pub fn new(height: Height, service_id: InstanceId) -> Self
Creates a new query.
Sourcepub fn with_proof(self) -> Self
pub fn with_proof(self) -> Self
Requests to return a call status with a cryptographic proof of authenticity.