#[non_exhaustive]pub struct TransactionStatusQuery {
pub hash: Hash,
pub with_proof: bool,
}Expand description
Query parameters to check the execution status of a transaction.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hash: HashThe hash of the transaction to be searched.
with_proof: boolWhether to return the status with a cryptographic proof of authenticity.
Implementations
Sourceimpl TransactionStatusQuery
impl TransactionStatusQuery
Sourcepub fn with_proof(self) -> Self
pub fn with_proof(self) -> Self
Requests to return a call status with a cryptographic proof of authenticity.